==> pentobi-18.1.tar.xz: pentobi-18.1/pentobi_thumbnailer/i18n/es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>main</name>
    <message>
        <source>thumbnailer for Blokus game records as used by Pentobi</source>
        <translation>miniaturizador para registros de partidas de Blokus según su uso por Pentobi</translation>
    </message>
    <message>
        <source>Generate image with height and width &lt;size&gt;.</source>
        <extracomment>Description for command line option --size</extracomment>
        <translation>Generar imagen con altura y anchura &lt;size&gt;.</translation>
    </message>
    <message>
        <source>size</source>
        <extracomment>Value name for command line option --size</extracomment>
        <translation>tamaño</translation>
    </message>
    <message>
        <source>input.blksgf</source>
        <extracomment>Name of input file command line argument.</extracomment>
        <translation>input.blksgf</translation>
    </message>
    <message>
        <source>Blokus SGF input file.</source>
        <translation>Archivo de entrada SGF de Blokus</translation>
    </message>
    <message>
        <source>output.png</source>
        <extracomment>Name of output image file command line argument.</extracomment>
        <translation>output.png</translation>
    </message>
    <message>
        <source>PNG image output file.</source>
        <translation>Archivo de imagen de salida PNG.</translation>
    </message>
    <message>
        <source>Invalid image size</source>
        <translation>Tamaño de imagen no válido</translation>
    </message>
    <message>
        <source>Too many arguments</source>
        <translation>Demasiados argumentos</translation>
    </message>
    <message>
        <source>Need input and output file argument</source>
        <translation>Es necesario argumento de archivo de entrada y salida</translation>
    </message>
    <message>
        <source>Thumbnail creation failed</source>
        <translation>Se produjo un error en la creación de la miniatura</translation>
    </message>
</context>
</TS>

==> pentobi_18.3.orig.tar.xz: pentobi-18.3/pentobi_thumbnailer/i18n/es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>main</name>
    <message>
        <source>thumbnailer for Blokus game records as used by Pentobi</source>
        <translation>miniaturizador para registros de partidas de Blokus según su uso por Pentobi</translation>
    </message>
    <message>
        <source>Generate image with height and width &lt;size&gt;.</source>
        <extracomment>Description for command line option --size</extracomment>
        <translation>Generar imagen con altura y anchura &lt;size&gt;.</translation>
    </message>
    <message>
        <source>size</source>
        <extracomment>Value name for command line option --size</extracomment>
        <translation>tamaño</translation>
    </message>
    <message>
        <source>input.blksgf</source>
        <extracomment>Name of input file command line argument.</extracomment>
        <translation>input.blksgf</translation>
    </message>
    <message>
        <source>Blokus SGF input file.</source>
        <translation>Archivo de entrada SGF de Blokus</translation>
    </message>
    <message>
        <source>output.png</source>
        <extracomment>Name of output image file command line argument.</extracomment>
        <translation>output.png</translation>
    </message>
    <message>
        <source>PNG image output file.</source>
        <translation>Archivo de imagen de salida PNG.</translation>
    </message>
    <message>
        <source>Invalid image size</source>
        <translation>Tamaño de imagen no válido</translation>
    </message>
    <message>
        <source>Too many arguments</source>
        <translation>Demasiados argumentos</translation>
    </message>
    <message>
        <source>Need input and output file argument</source>
        <translation>Es necesario argumento de archivo de entrada y salida</translation>
    </message>
    <message>
        <source>Thumbnail creation failed</source>
        <translation>Se produjo un error en la creación de la miniatura</translation>
    </message>
</context>
</TS>
